/****************************************************************************\
**  Title:        PCXREAD                                                   **
**  Purpose:      Read PCX header information from a file.                  **
**  Version:      1.0                                                       **
**  Date:         May 1991                                                  **
**  Author:       James D. Murray, Anaheim, CA  USA                         **
**  C Compilers:  Borland C++ v2.0, Microsoft C v6.00a                      **
**                                                                          **
**  Read the header information contained within a PCX-format file and      **
**  store it in a PCXHEADER structure.                                      **
**                                                                          **
**  This module contains the following functions:                           **
**                                                                          **
**      ReadPcxHeader - Read a PCX header to a structure                    **
**                                                                          **
**  Copyright (C) 1991 Graphics Software Labs.  All rights reserved.        **
\****************************************************************************/
#include <stdio.h>
#include "endianio.h"
#include "pcx.h"

WORD (*GetWord)(FILE *);        /* Pointer to ENDIANIO function */

/*
**  Read the information from a PCX image file header.
**
**  PCX header file information is read fromn the supplied FILE
**  stream and written to the supplied PCX header structure.
**  The ENDIANIO I/O finctions are used to insure that the header
**  information is written in little-endian order.
**
**  Returns: Nothing.
*/
VOID
ReadPcxHeader(PcxHead, FpPcx)
PCXHEADER *PcxHead;     /* Pointer to PCX header structure  */
FILE      *FpPcx;       /* PCX image file input FILE stream */
{
    register SHORT i;

    GetWord = GetLittleWord;    /* Initialize ENDIANIO read function */

    PcxHead->Id             = GetByte(FpPcx);
    PcxHead->Version        = GetByte(FpPcx);
    PcxHead->Format         = GetByte(FpPcx);
    PcxHead->BitsPixelPlane = GetByte(FpPcx);
    PcxHead->Xmin           = GetWord(FpPcx);
    PcxHead->Ymin           = GetWord(FpPcx);
    PcxHead->Xmax           = GetWord(FpPcx);
    PcxHead->Ymax           = GetWord(FpPcx);
    PcxHead->Hdpi           = GetWord(FpPcx);
    PcxHead->Vdpi           = GetWord(FpPcx);

    /* Read the EGA Palette */
    for (i = 0; i < sizeof(PcxHead->EgaPalette); i++)
        PcxHead->EgaPalette[i] = GetByte(FpPcx);

    PcxHead->Reserved       = GetByte(FpPcx);       
    PcxHead->NumberOfPlanes = GetByte(FpPcx);
    PcxHead->BytesLinePlane = GetWord(FpPcx); 
    PcxHead->PaletteInfo    = GetWord(FpPcx);  
    PcxHead->HScreenSize    = GetWord(FpPcx);  
    PcxHead->VScreenSize    = GetWord(FpPcx);

    /* Read the reserved area at the end of the header */
    for (i = 0; i < sizeof(PcxHead->Filler); i++)
        PcxHead->Filler[i] = GetByte(FpPcx);
}
}
